#include "LED.cpp"
#include "BluetoothLEDCallback.cpp"
#include "BluetoothLightControl.cpp"
#include "BluetoothService.cpp"
#include "EspNowControl.cpp"
#include "LedManager.cpp"
#include "TimerManager.cpp"
#include "TouchInput.cpp"
#include <Arduino.h>

LedManager *EspNowControl::_leds = 0; // WTF, C++?

#define FADE_IN_DURATION 500
#define FADE_OUT_DURATION 1000

LEDOutput _seatingLedOutput(0, true);
LED _seatingLeds("seating", &_seatingLedOutput, FADE_IN_DURATION, FADE_OUT_DURATION);
LEDOutput _kitchenLedOutput(1, true);
LED _kitchenLeds("kitchen", &_kitchenLedOutput, FADE_IN_DURATION, FADE_OUT_DURATION);
LEDOutput _bathroomLedOutput(2, true);
LED _bathroomLeds("bathroom", &_bathroomLedOutput, FADE_IN_DURATION, FADE_OUT_DURATION);

LEDOutput _awningLedOutput(3);
LED _awningLeds("awning", &_awningLedOutput, FADE_IN_DURATION, FADE_OUT_DURATION);

LEDOutput _cabLedOutput(4);
LED _cabLeds("cab", &_cabLedOutput, FADE_IN_DURATION, FADE_OUT_DURATION);

TimerManager _timers;
LedManager _leds(&_timers);
BluetoothLightControl _bluetoothLightControl(&_leds);
BluetoothLEDCallback _btCallback(&_bluetoothLightControl);
BluetoothService _btService("Van Lights", &_btCallback);
TouchInput _mainTouchInput(33, 9, []() {
	_seatingLeds.toggle();
	_kitchenLeds.toggle();
	_bathroomLeds.toggle();
});
// TouchInput _cabTouchInput(32, 1, []() {
// 	_cabLeds.toggle();
// });

void setup() {
	Serial.begin(115200);

	_seatingLedOutput.attach(16);
	_seatingLedOutput.attach(17);

	_kitchenLedOutput.attach(5);
	_kitchenLedOutput.attach(18);
	_kitchenLedOutput.attach(23);

	_bathroomLedOutput.attach(19);

	_awningLedOutput.attach(22);

	_cabLedOutput.attach(4);

	_leds.registerLEDs(1, &_seatingLeds);
	_leds.registerLEDs(2, &_kitchenLeds);
	_leds.registerLEDs(3, &_bathroomLeds);
	_leds.registerLEDs(4, &_awningLeds);
	_leds.registerLEDs(5, &_cabLeds);

	_btService.init();
	_btService.start();
	EspNowControl::init(&_leds);
}

void loop() {
	_timers.loop();
	_leds.loop();
	_mainTouchInput.loop();
	//_cabTouchInput.loop();
}
